@@ -48,10 +48,9 @@ impl DenseLuaGenerator {
             self.raw_push_char(character);
         } else {
             let last_push_content = self.get_last_push_str().to_owned();
-            (0..self.last_push_length)
-                .for_each(|_| {
-                    self.output.pop();
-                });
+            (0..self.last_push_length).for_each(|_| {
+                self.output.pop();
+            });
 
             let mut last_char = self.output.pop();
 
@@ -84,10 +83,8 @@ impl DenseLuaGenerator {
                     self.output.push(' ');
                     self.current_line_length += 1;
                 }
-            } else {
-                if total_length > self.column_span {
-                    self.push_new_line();
-                }
+            } else if total_length > self.column_span {
+                self.push_new_line();
             }
         }
     }
@@ -112,7 +109,12 @@ impl DenseLuaGenerator {
     #[inline]
     fn needs_space(&self, next_character: char) -> bool {
         is_relevant_for_spacing(&next_character)
-        && self.output.chars().last().filter(is_relevant_for_spacing).is_some()
+            && self
+                .output
+                .chars()
+                .last()
+                .filter(is_relevant_for_spacing)
+                .is_some()
     }
 
     /// Consumes the LuaGenerator and produce a String object.
@@ -137,7 +139,8 @@ impl DenseLuaGenerator {
     /// This function only insert a space or a new line if the given predicate returns true. In
     /// the other case, the string is added to the current generator content.
     fn push_str_and_break_if<F>(&mut self, content: &str, predicate: F)
-        where F: Fn(&str) -> bool
+    where
+        F: Fn(&str) -> bool,
     {
         if predicate(self.get_last_push_str()) {
             if self.fits_on_current_line(1 + content.len()) {
@@ -145,39 +148,45 @@ impl DenseLuaGenerator {
             } else {
                 self.push_new_line();
             }
-        } else {
-            if !self.fits_on_current_line(content.len()) {
-                self.push_new_line();
-            }
+        } else if !self.fits_on_current_line(content.len()) {
+            self.push_new_line();
         }
         self.raw_push_str(content);
     }
 
     fn get_last_push_str(&self) -> &str {
-        self.output.get((self.output.len() - self.last_push_length)..)
+        self.output
+            .get((self.output.len() - self.last_push_length)..)
             .unwrap_or("")
     }
 
-    fn write_function_parameters(&mut self, parameters: &Vec<String>, is_variadic: bool) {
-        let last_index = parameters.len().checked_sub(1).unwrap_or(0);
+    fn write_function_parameters(&mut self, parameters: &[String], is_variadic: bool) {
+        let last_index = parameters.len().saturating_sub(1);
 
-        parameters.iter()
-            .enumerate()
-            .for_each(|(index, variable)| {
-                self.push_str(variable);
+        parameters.iter().enumerate().for_each(|(index, variable)| {
+            self.push_str(variable);
 
-                if index != last_index {
-                    self.push_char(',');
-                }
-            });
+            if index != last_index {
+                self.push_char(',');
+            }
+        });
 
         if is_variadic {
-            if parameters.len() > 0 {
+            if !parameters.is_empty() {
                 self.push_char(',');
             };
             self.push_str("...");
         };
     }
+
+    fn write_variable(&mut self, variable: &nodes::Variable) {
+        use nodes::Variable::*;
+        match variable {
+            Identifier(identifier) => self.push_str(identifier),
+            Field(field) => self.write_field(field),
+            Index(index) => self.write_index(index),
+        }
+    }
 }
 
 impl Default for DenseLuaGenerator {
@@ -200,9 +209,7 @@ impl LuaGenerator for DenseLuaGenerator {
             self.write_statement(statement);
 
             if let Some(next_statement) = statements.peek() {
-                if starts_with_parenthese(next_statement)
-                    && ends_with_prefix(statement)
-                {
+                if starts_with_parenthese(next_statement) && ends_with_prefix(statement) {
                     self.push_char(';');
                 }
             }
@@ -217,36 +224,26 @@ impl LuaGenerator for DenseLuaGenerator {
         let variables = assign.get_variables();
         let last_variable_index = variables.len() - 1;
 
-        variables.iter()
-            .enumerate()
-            .for_each(|(index, variable)| {
-                use nodes::Variable::*;
+        variables.iter().enumerate().for_each(|(index, variable)| {
+            self.write_variable(variable);
 
-                match variable {
-                    Identifier(identifier) => self.push_str(identifier),
-                    Field(field) => self.write_field(field),
-                    Index(index) => self.write_index(index),
-                }
-
-                if index != last_variable_index {
-                    self.push_char(',');
-                }
-            });
+            if index != last_variable_index {
+                self.push_char(',');
+            }
+        });
 
         self.push_char('=');
 
         let values = assign.get_values();
         let last_value_index = values.len() - 1;
 
-        values.iter()
-            .enumerate()
-            .for_each(|(index, value)| {
-                self.write_expression(value);
+        values.iter().enumerate().for_each(|(index, value)| {
+            self.write_expression(value);
 
-                if index != last_value_index {
-                    self.push_char(',');
-                }
-            });
+            if index != last_value_index {
+                self.push_char(',');
+            }
+        });
     }
 
     fn write_do_statement(&mut self, do_statement: &nodes::DoStatement) {
@@ -259,8 +256,10 @@ impl LuaGenerator for DenseLuaGenerator {
         self.push_str("for");
 
         let identifiers = generic_for.get_identifiers();
-        let last_identifier_index = identifiers.len().checked_sub(1).unwrap_or(0);
-        identifiers.iter().enumerate()
+        let last_identifier_index = identifiers.len().saturating_sub(1);
+        identifiers
+            .iter()
+            .enumerate()
             .for_each(|(index, identifier)| {
                 self.push_str(identifier);
 
@@ -271,8 +270,10 @@ impl LuaGenerator for DenseLuaGenerator {
         self.push_str("in");
 
         let expressions = generic_for.get_expressions();
-        let last_expression_index = expressions.len().checked_sub(1).unwrap_or(0);
-        expressions.iter().enumerate()
+        let last_expression_index = expressions.len().saturating_sub(1);
+        expressions
+            .iter()
+            .enumerate()
             .for_each(|(index, expression)| {
                 self.write_expression(expression);
 
@@ -289,19 +290,17 @@ impl LuaGenerator for DenseLuaGenerator {
     fn write_if_statement(&mut self, if_statement: &nodes::IfStatement) {
         let branches = if_statement.get_branches();
 
-        branches.iter()
-            .enumerate()
-            .for_each(|(index, branch)| {
-                if index == 0 {
-                    self.push_str("if");
-                } else {
-                    self.push_str("elseif");
-                }
+        branches.iter().enumerate().for_each(|(index, branch)| {
+            if index == 0 {
+                self.push_str("if");
+            } else {
+                self.push_str("elseif");
+            }
 
-                self.write_expression(branch.get_condition());
-                self.push_str("then");
-                self.write_block(branch.get_block());
-            });
+            self.write_expression(branch.get_condition());
+            self.push_str("then");
+            self.write_block(branch.get_block());
+        });
 
         if let Some(else_block) = if_statement.get_else_block() {
             self.push_str("else");
@@ -316,11 +315,10 @@ impl LuaGenerator for DenseLuaGenerator {
         let name = function.get_name();
 
         self.push_str(name.get_name());
-        name.get_field_names().iter()
-            .for_each(|field| {
-                self.push_char('.');
-                self.push_str(field);
-            });
+        name.get_field_names().iter().for_each(|field| {
+            self.push_char('.');
+            self.push_str(field);
+        });
 
         if let Some(method) = name.get_method() {
             self.push_char(':');
@@ -333,12 +331,10 @@ impl LuaGenerator for DenseLuaGenerator {
 
         let block = function.get_block();
 
-        if block.is_empty() {
-            self.push_str("end");
-        } else {
+        if !block.is_empty() {
             self.write_block(block);
-            self.push_str("end");
         }
+        self.push_str("end");
     }
 
     fn write_last_statement(&mut self, statement: &nodes::LastStatement) {
@@ -346,11 +342,13 @@ impl LuaGenerator for DenseLuaGenerator {
 
         match statement {
             Break => self.push_str("break"),
+            Continue => self.push_str("continue"),
             Return(expressions) => {
                 self.push_str("return");
-                let last_index = expressions.len().checked_sub(1).unwrap_or(0);
+                let last_index = expressions.len().saturating_sub(1);
 
-                expressions.iter()
+                expressions
+                    .iter()
                     .enumerate()
                     .for_each(|(index, expression)| {
                         self.write_expression(expression);
@@ -359,8 +357,7 @@ impl LuaGenerator for DenseLuaGenerator {
                             self.push_char(',');
                         }
                     });
-
-            },
+            }
         }
     }
 
@@ -368,37 +365,41 @@ impl LuaGenerator for DenseLuaGenerator {
         self.push_str("local");
 
         let variables = assign.get_variables();
-        let last_variable_index = variables.len().checked_sub(1).unwrap_or(0);
+        let last_variable_index = variables.len().saturating_sub(1);
 
-        variables.iter()
-            .enumerate()
-            .for_each(|(index, variable)| {
-                self.push_str(variable);
+        variables.iter().enumerate().for_each(|(index, variable)| {
+            self.push_str(variable);
 
-                if index != last_variable_index {
-                    self.push_char(',');
-                }
-            });
+            if index != last_variable_index {
+                self.push_char(',');
+            }
+        });
 
         let values = assign.get_values();
 
-        if values.len() > 0 {
+        if !values.is_empty() {
             self.push_char('=');
 
             let last_value_index = values.len() - 1;
 
-            values.iter()
-                .enumerate()
-                .for_each(|(index, value)| {
-                    self.write_expression(value);
+            values.iter().enumerate().for_each(|(index, value)| {
+                self.write_expression(value);
 
-                    if index != last_value_index {
-                        self.push_char(',');
-                    }
-                });
+                if index != last_value_index {
+                    self.push_char(',');
+                }
+            });
         };
     }
 
+    fn write_compound_assign(&mut self, assign: &nodes::CompoundAssignStatement) {
+        self.write_variable(assign.get_variable());
+
+        self.push_str(assign.get_operator().to_str());
+
+        self.write_expression(assign.get_value());
+    }
+
     fn write_local_function(&mut self, function: &nodes::LocalFunctionStatement) {
         self.push_str("local function");
         self.push_str(function.get_name());
@@ -410,12 +411,10 @@ impl LuaGenerator for DenseLuaGenerator {
 
         let block = function.get_block();
 
-        if block.is_empty() {
-            self.push_str("end");
-        } else {
+        if !block.is_empty() {
             self.write_block(block);
-            self.push_str("end");
         }
+        self.push_str("end");
     }
 
     fn write_numeric_for(&mut self, numeric_for: &nodes::NumericForStatement) {
@@ -448,13 +447,11 @@ impl LuaGenerator for DenseLuaGenerator {
 
         let block = repeat.get_block();
 
-        if block.is_empty() {
-            self.push_str("until");
-        } else {
+        if !block.is_empty() {
             self.write_block(block);
-            self.push_str("until");
         }
 
+        self.push_str("until");
         self.write_expression(repeat.get_condition());
     }
 
@@ -507,7 +504,7 @@ impl LuaGenerator for DenseLuaGenerator {
         let left = binary.left();
         let right = binary.right();
 
-        if operator.left_needs_parentheses(&left) {
+        if operator.left_needs_parentheses(left) {
             self.push_char('(');
             self.write_expression(left);
             self.push_char(')');
@@ -520,7 +517,7 @@ impl LuaGenerator for DenseLuaGenerator {
             _ => self.push_str(operator.to_str()),
         }
 
-        if operator.right_needs_parentheses(&right) {
+        if operator.right_needs_parentheses(right) {
             self.push_char('(');
             self.write_expression(right);
             self.push_char(')');
@@ -545,7 +542,7 @@ impl LuaGenerator for DenseLuaGenerator {
                 self.push_char('(');
                 self.write_expression(expression);
                 self.push_char(')');
-            },
+            }
             _ => self.write_expression(expression),
         }
     }
@@ -560,12 +557,10 @@ impl LuaGenerator for DenseLuaGenerator {
 
         let block = function.get_block();
 
-        if block.is_empty() {
-            self.push_str("end");
-        } else {
+        if !block.is_empty() {
             self.write_block(block);
-            self.push_str("end");
         }
+        self.push_str("end");
     }
 
     fn write_function_call(&mut self, call: &nodes::FunctionCall) {
@@ -573,7 +568,7 @@ impl LuaGenerator for DenseLuaGenerator {
 
         if let Some(method) = &call.get_method() {
             self.push_char(':');
-            self.push_str(&method);
+            self.push_str(method);
         }
 
         self.write_arguments(call.get_arguments());
@@ -583,7 +578,7 @@ impl LuaGenerator for DenseLuaGenerator {
         self.write_prefix(field.get_prefix());
 
         self.push_char('.');
-        self.push_str(&field.get_field());
+        self.push_str(field.get_field());
     }
 
     fn write_index(&mut self, index: &nodes::IndexExpression) {
@@ -614,17 +609,15 @@ impl LuaGenerator for DenseLuaGenerator {
         self.push_char('{');
 
         let entries = table.get_entries();
-        let last_index = entries.len().checked_sub(1).unwrap_or(0);
+        let last_index = entries.len().saturating_sub(1);
 
-        entries.iter()
-            .enumerate()
-            .for_each(|(index, entry)| {
-                self.write_table_entry(entry);
+        entries.iter().enumerate().for_each(|(index, entry)| {
+            self.write_table_entry(entry);
 
-                if index != last_index {
-                    self.push_char(',');
-                }
-            });
+            if index != last_index {
+                self.push_char(',');
+            }
+        });
 
         self.push_char('}');
     }
@@ -674,7 +667,8 @@ impl LuaGenerator for DenseLuaGenerator {
                     let mut result = format!("{:.}", float);
 
                     if let Some(exponent) = number.get_exponent() {
-                        let exponent_char = number.is_uppercase()
+                        let exponent_char = number
+                            .is_uppercase()
                             .map(|is_uppercase| if is_uppercase { 'E' } else { 'e' })
                             .unwrap_or('e');
 
@@ -693,7 +687,8 @@ impl LuaGenerator for DenseLuaGenerator {
                 );
 
                 if let Some(exponent) = number.get_exponent() {
-                    let exponent_char = number.is_exponent_uppercase()
+                    let exponent_char = number
+                        .is_exponent_uppercase()
                         .map(|is_uppercase| if is_uppercase { 'P' } else { 'p' })
                         .unwrap_or('p');
 
@@ -703,6 +698,13 @@ impl LuaGenerator for DenseLuaGenerator {
 
                 self.push_str(&result);
             }
+            Binary(number) => {
+                self.push_str(&format!(
+                    "0{}{:b}",
+                    if number.is_b_uppercase() { 'B' } else { 'b' },
+                    number.get_raw_value()
+                ));
+            }
         }
     }
 
@@ -714,8 +716,10 @@ impl LuaGenerator for DenseLuaGenerator {
             Tuple(expressions) => {
                 self.merge_char('(');
 
-                let last_index = expressions.len().checked_sub(1).unwrap_or(0);
-                expressions.iter().enumerate()
+                let last_index = expressions.len().saturating_sub(1);
+                expressions
+                    .iter()
+                    .enumerate()
                     .for_each(|(index, expression)| {
                         self.write_expression(expression);
 
@@ -736,8 +740,8 @@ impl LuaGenerator for DenseLuaGenerator {
             let mut equals = "=".repeat(i);
 
             loop {
-                if value.find(&format!("]{}]", equals)).is_none() {
-                    break
+                if !value.contains(&format!("]{}]", equals)) {
+                    break;
                 } else {
                     i += 1;
                     equals = "=".repeat(i);
@@ -746,9 +750,8 @@ impl LuaGenerator for DenseLuaGenerator {
 
             self.push_str_and_break_if(
                 &format!("[{}[{}]{}]", equals, value, equals),
-                break_long_string
+                break_long_string,
             );
-
         } else {
             let string = if string.has_single_quote() {
                 if string.has_double_quote() {
