@@ -6,6 +6,7 @@ enum StatementType {
     Assign,
     Do,
     Call,
+    CompoundAssign,
     Function,
     GenericFor,
     If,
@@ -16,6 +17,7 @@ enum StatementType {
     While,
     Return,
     Break,
+    Continue,
 }
 
 impl From<&nodes::Statement> for StatementType {
@@ -25,6 +27,7 @@ impl From<&nodes::Statement> for StatementType {
             Assign(_) => Self::Assign,
             Do(_) => Self::Do,
             Call(_) => Self::Call,
+            CompoundAssign(_) => Self::CompoundAssign,
             Function(_) => Self::Function,
             GenericFor(_) => Self::GenericFor,
             If(_) => Self::If,
@@ -42,6 +45,7 @@ impl From<&nodes::LastStatement> for StatementType {
         use nodes::LastStatement::*;
         match statement {
             Break => Self::Break,
+            Continue => Self::Continue,
             Return(_) => Self::Return,
         }
     }
@@ -75,9 +79,7 @@ impl ReadableLuaGenerator {
 
     #[inline]
     fn can_add_new_line(&self) -> bool {
-        self.can_add_new_line_stack.last()
-            .copied()
-            .unwrap_or(true)
+        self.can_add_new_line_stack.last().copied().unwrap_or(true)
     }
 
     #[inline]
@@ -158,7 +160,12 @@ impl ReadableLuaGenerator {
     #[inline]
     fn needs_space(&self, next_character: char) -> bool {
         is_relevant_for_spacing(&next_character)
-        && self.output.chars().last().filter(is_relevant_for_spacing).is_some()
+            && self
+                .output
+                .chars()
+                .last()
+                .filter(is_relevant_for_spacing)
+                .is_some()
     }
 
     #[inline]
@@ -185,23 +192,20 @@ impl ReadableLuaGenerator {
                     } else {
                         self.push_space();
                     }
-                } else {
-                    if total_length > self.column_span {
-                        self.push_new_line();
-                    }
+                } else if total_length > self.column_span {
+                    self.push_new_line();
                 }
             }
-        } else {
-            if self.needs_space(next_character) {
-                self.push_space();
-            }
+        } else if self.needs_space(next_character) {
+            self.push_space();
         }
     }
 
     /// This function only insert a space or a new line if the given predicate returns true. In
     /// the other case, the string is added to the current generator content.
     fn push_str_and_break_if<F>(&mut self, content: &str, predicate: F)
-        where F: Fn(&str) -> bool
+    where
+        F: Fn(&str) -> bool,
     {
         if predicate(self.get_last_push_str()) {
             if self.fits_on_current_line(1 + content.len()) {
@@ -209,59 +213,49 @@ impl ReadableLuaGenerator {
             } else {
                 self.push_new_line();
             }
-        } else {
-            if !self.fits_on_current_line(content.len()) {
-                self.push_new_line();
-            }
+        } else if !self.fits_on_current_line(content.len()) {
+            self.push_new_line();
         }
         self.raw_push_str(content);
     }
 
     fn get_last_push_str(&self) -> &str {
-        self.output.get((self.output.len() - self.last_push_length)..)
+        self.output
+            .get((self.output.len() - self.last_push_length)..)
             .unwrap_or("")
     }
 
-    fn table_fits_on_line(&self, entries: &Vec<nodes::TableEntry>, _width: usize) -> bool {
+    fn table_fits_on_line(&self, entries: &[nodes::TableEntry], _width: usize) -> bool {
         use nodes::TableEntry;
 
         // small list of simple expressions
         entries.len() < 4
-        && entries.iter()
-            .all(|entry| match entry {
+            && entries.iter().all(|entry| match entry {
                 TableEntry::Value(value) => self.is_small_expression(value),
                 _ => false,
             })
-        ||
-        entries.len() == 1
-        && entries.iter()
-            .all(|entry| match entry {
-                TableEntry::Field(_identifier, value) => {
-                    self.is_small_expression(value)
-                }
-                TableEntry::Index(key, value) => {
-                    self.is_small_expression(key) && self.is_small_expression(value)
-                }
-                _ => false,
-            })
+            || entries.len() == 1
+                && entries.iter().all(|entry| match entry {
+                    TableEntry::Field(_identifier, value) => self.is_small_expression(value),
+                    TableEntry::Index(key, value) => {
+                        self.is_small_expression(key) && self.is_small_expression(value)
+                    }
+                    _ => false,
+                })
     }
 
     fn is_small_expression(&self, expression: &nodes::Expression) -> bool {
         use nodes::Expression::*;
         match expression {
-            True
-            | False
-            | Nil
-            | Identifier(_)
-            | VariableArguments
-            | Number(_) => true,
-            Table(table) => table.len() == 0,
+            True | False | Nil | Identifier(_) | VariableArguments | Number(_) => true,
+            Table(table) => table.is_empty(),
             _ => false,
         }
     }
 
-    fn write_function_parameters(&mut self, parameters: &Vec<String>, is_variadic: bool) {
-        let mut parameters_length = parameters.iter()
+    fn write_function_parameters(&mut self, parameters: &[String], is_variadic: bool) {
+        let mut parameters_length = parameters
+            .iter()
             .fold(0, |acc, parameter| acc + parameter.len());
         // add a comma and a space between each parameter
         parameters_length += parameters.len() * 2;
@@ -275,22 +269,20 @@ impl ReadableLuaGenerator {
             }
         }
 
-        let last_index = parameters.len().checked_sub(1).unwrap_or(0);
+        let last_index = parameters.len().saturating_sub(1);
 
         if self.fits_on_current_line(parameters_length) {
-            parameters.iter()
-                .enumerate()
-                .for_each(|(index, variable)| {
-                    self.raw_push_str(variable);
+            parameters.iter().enumerate().for_each(|(index, variable)| {
+                self.raw_push_str(variable);
 
-                    if index != last_index {
-                        self.raw_push_char(',');
-                        self.raw_push_char(' ');
-                    }
-                });
+                if index != last_index {
+                    self.raw_push_char(',');
+                    self.raw_push_char(' ');
+                }
+            });
 
             if is_variadic {
-                if parameters.len() > 0 {
+                if !parameters.is_empty() {
                     self.raw_push_char(',');
                     self.raw_push_char(' ');
                 };
@@ -299,20 +291,18 @@ impl ReadableLuaGenerator {
         } else {
             self.push_indentation();
 
-            parameters.iter()
-                .enumerate()
-                .for_each(|(index, variable)| {
-                    self.push_new_line();
-                    self.write_indentation();
-                    self.raw_push_str(variable);
+            parameters.iter().enumerate().for_each(|(index, variable)| {
+                self.push_new_line();
+                self.write_indentation();
+                self.raw_push_str(variable);
 
-                    if index != last_index {
-                        self.raw_push_char(',');
-                    }
-                });
+                if index != last_index {
+                    self.raw_push_char(',');
+                }
+            });
 
             if is_variadic {
-                if parameters.len() > 0 {
+                if !parameters.is_empty() {
                     self.raw_push_char(',');
                 };
                 self.push_new_line();
@@ -325,6 +315,15 @@ impl ReadableLuaGenerator {
             self.write_indentation();
         }
     }
+
+    fn write_variable(&mut self, variable: &nodes::Variable) {
+        use nodes::Variable::*;
+        match variable {
+            Identifier(identifier) => self.push_str(identifier),
+            Field(field) => self.write_field(field),
+            Index(index) => self.write_index(index),
+        }
+    }
 }
 
 impl Default for ReadableLuaGenerator {
@@ -349,9 +348,7 @@ impl LuaGenerator for ReadableLuaGenerator {
             self.write_statement(statement);
 
             if let Some(next_statement) = statements.peek() {
-                if starts_with_parenthese(next_statement)
-                    && ends_with_prefix(statement)
-                {
+                if starts_with_parenthese(next_statement) && ends_with_prefix(statement) {
                     self.push_char(';');
                 }
 
@@ -362,10 +359,10 @@ impl LuaGenerator for ReadableLuaGenerator {
 
             self.pop_can_add_new_line();
             self.push_new_line();
-        };
+        }
 
         if let Some(last_statement) = block.get_last_statement() {
-            if block.get_statements().len() != 0 {
+            if !block.get_statements().is_empty() {
                 self.push_new_line();
             }
             self.write_last_statement(last_statement);
@@ -378,12 +375,14 @@ impl LuaGenerator for ReadableLuaGenerator {
 
         match statement {
             Break => self.push_str("break"),
+            Continue => self.push_str("continue"),
             Return(expressions) => {
                 self.push_str("return");
                 self.push_can_add_new_line(false);
-                let last_index = expressions.len().checked_sub(1).unwrap_or(0);
+                let last_index = expressions.len().saturating_sub(1);
 
-                expressions.iter()
+                expressions
+                    .iter()
                     .enumerate()
                     .for_each(|(index, expression)| {
                         self.write_expression(expression);
@@ -395,7 +394,7 @@ impl LuaGenerator for ReadableLuaGenerator {
                     });
 
                 self.pop_can_add_new_line();
-            },
+            }
         }
     }
 
@@ -404,37 +403,27 @@ impl LuaGenerator for ReadableLuaGenerator {
 
         let variables = assign.get_variables();
         let last_variable_index = variables.len() - 1;
-        variables.iter()
-            .enumerate()
-            .for_each(|(index, variable)| {
-                use nodes::Variable::*;
+        variables.iter().enumerate().for_each(|(index, variable)| {
+            self.write_variable(variable);
 
-                match variable {
-                    Identifier(identifier) => self.push_str(identifier),
-                    Field(field) => self.write_field(field),
-                    Index(index) => self.write_index(index),
-                }
-
-                if index != last_variable_index {
-                    self.raw_push_char(',');
-                    self.raw_push_char(' ');
-                }
-            });
+            if index != last_variable_index {
+                self.raw_push_char(',');
+                self.raw_push_char(' ');
+            }
+        });
 
         self.raw_push_str(" = ");
 
         let values = assign.get_values();
         let last_value_index = values.len() - 1;
-        values.iter()
-            .enumerate()
-            .for_each(|(index, value)| {
-                self.write_expression(value);
+        values.iter().enumerate().for_each(|(index, value)| {
+            self.write_expression(value);
 
-                if index != last_value_index {
-                    self.raw_push_char(',');
-                    self.raw_push_char(' ');
-                }
-            });
+            if index != last_value_index {
+                self.raw_push_char(',');
+                self.raw_push_char(' ');
+            }
+        });
 
         self.pop_can_add_new_line();
     }
@@ -445,41 +434,51 @@ impl LuaGenerator for ReadableLuaGenerator {
         self.push_can_add_new_line(false);
 
         let variables = assign.get_variables();
-        let last_variable_index = variables.len().checked_sub(1).unwrap_or(0);
+        let last_variable_index = variables.len().saturating_sub(1);
 
-        variables.iter()
-            .enumerate()
-            .for_each(|(index, variable)| {
-                self.raw_push_str(variable);
+        variables.iter().enumerate().for_each(|(index, variable)| {
+            self.raw_push_str(variable);
 
-                if index != last_variable_index {
-                    self.raw_push_char(',');
-                    self.raw_push_char(' ');
-                }
-            });
+            if index != last_variable_index {
+                self.raw_push_char(',');
+                self.raw_push_char(' ');
+            }
+        });
 
         let values = assign.get_values();
 
-        if values.len() > 0 {
+        if !values.is_empty() {
             self.raw_push_str(" = ");
 
             let last_value_index = values.len() - 1;
 
-            values.iter()
-                .enumerate()
-                .for_each(|(index, value)| {
-                    self.write_expression(value);
+            values.iter().enumerate().for_each(|(index, value)| {
+                self.write_expression(value);
 
-                    if index != last_value_index {
-                        self.raw_push_char(',');
-                        self.raw_push_char(' ');
-                    }
-                });
+                if index != last_value_index {
+                    self.raw_push_char(',');
+                    self.raw_push_char(' ');
+                }
+            });
         };
 
         self.pop_can_add_new_line();
     }
 
+    fn write_compound_assign(&mut self, assign: &nodes::CompoundAssignStatement) {
+        self.push_can_add_new_line(false);
+
+        self.write_variable(assign.get_variable());
+
+        self.raw_push_char(' ');
+        self.raw_push_str(assign.get_operator().to_str());
+        self.push_space();
+
+        self.write_expression(assign.get_value());
+
+        self.pop_can_add_new_line();
+    }
+
     fn write_local_function(&mut self, function: &nodes::LocalFunctionStatement) {
         self.push_str("local function ");
         self.raw_push_str(function.get_name());
@@ -504,8 +503,10 @@ impl LuaGenerator for ReadableLuaGenerator {
         self.push_str("for ");
 
         let identifiers = generic_for.get_identifiers();
-        let last_identifier_index = identifiers.len().checked_sub(1).unwrap_or(0);
-        identifiers.iter().enumerate()
+        let last_identifier_index = identifiers.len().saturating_sub(1);
+        identifiers
+            .iter()
+            .enumerate()
             .for_each(|(index, identifier)| {
                 self.raw_push_str(identifier);
 
@@ -518,8 +519,10 @@ impl LuaGenerator for ReadableLuaGenerator {
         self.raw_push_str(" in ");
 
         let expressions = generic_for.get_expressions();
-        let last_expression_index = expressions.len().checked_sub(1).unwrap_or(0);
-        expressions.iter().enumerate()
+        let last_expression_index = expressions.len().saturating_sub(1);
+        expressions
+            .iter()
+            .enumerate()
             .for_each(|(index, expression)| {
                 self.write_expression(expression);
 
@@ -572,20 +575,18 @@ impl LuaGenerator for ReadableLuaGenerator {
     fn write_if_statement(&mut self, if_statement: &nodes::IfStatement) {
         let branches = if_statement.get_branches();
 
-        branches.iter()
-            .enumerate()
-            .for_each(|(index, branch)| {
-                if index == 0 {
-                    self.push_str("if ");
-                } else {
-                    self.push_str("elseif ");
-                }
+        branches.iter().enumerate().for_each(|(index, branch)| {
+            if index == 0 {
+                self.push_str("if ");
+            } else {
+                self.push_str("elseif ");
+            }
 
-                self.write_expression(branch.get_condition());
-                self.raw_push_str(" then");
-                self.push_new_line();
-                self.indent_and_write_block(branch.get_block());
-            });
+            self.write_expression(branch.get_condition());
+            self.raw_push_str(" then");
+            self.push_new_line();
+            self.indent_and_write_block(branch.get_block());
+        });
 
         if let Some(else_block) = if_statement.get_else_block() {
             self.push_str("else");
@@ -601,11 +602,10 @@ impl LuaGenerator for ReadableLuaGenerator {
         let name = function.get_name();
 
         self.raw_push_str(name.get_name());
-        name.get_field_names().iter()
-            .for_each(|field| {
-                self.raw_push_char('.');
-                self.raw_push_str(field);
-            });
+        name.get_field_names().iter().for_each(|field| {
+            self.raw_push_char('.');
+            self.raw_push_str(field);
+        });
 
         if let Some(method) = name.get_method() {
             self.raw_push_char(':');
@@ -708,7 +708,7 @@ impl LuaGenerator for ReadableLuaGenerator {
         let left = binary.left();
         let right = binary.right();
 
-        if operator.left_needs_parentheses(&left) {
+        if operator.left_needs_parentheses(left) {
             self.push_char('(');
             self.write_expression(left);
             self.push_char(')');
@@ -720,7 +720,7 @@ impl LuaGenerator for ReadableLuaGenerator {
         self.push_str(binary.operator().to_str());
         self.push_space();
 
-        if operator.right_needs_parentheses(&right) {
+        if operator.right_needs_parentheses(right) {
             self.push_char('(');
             self.write_expression(right);
             self.push_char(')');
@@ -745,7 +745,7 @@ impl LuaGenerator for ReadableLuaGenerator {
                 self.push_char('(');
                 self.write_expression(expression);
                 self.push_char(')');
-            },
+            }
             _ => self.write_expression(expression),
         }
     }
@@ -774,7 +774,7 @@ impl LuaGenerator for ReadableLuaGenerator {
 
         if let Some(method) = &call.get_method() {
             self.push_char(':');
-            self.push_str(&method);
+            self.push_str(method);
         }
 
         self.write_arguments(call.get_arguments());
@@ -790,8 +790,10 @@ impl LuaGenerator for ReadableLuaGenerator {
             Tuple(expressions) => {
                 self.raw_push_char('(');
 
-                let last_index = expressions.len().checked_sub(1).unwrap_or(0);
-                expressions.iter().enumerate()
+                let last_index = expressions.len().saturating_sub(1);
+                expressions
+                    .iter()
+                    .enumerate()
                     .for_each(|(index, expression)| {
                         self.write_expression(expression);
 
@@ -812,7 +814,7 @@ impl LuaGenerator for ReadableLuaGenerator {
         self.pop_can_add_new_line();
 
         self.push_char('.');
-        self.raw_push_str(&field.get_field());
+        self.raw_push_str(field.get_field());
     }
 
     fn write_index(&mut self, index: &nodes::IndexExpression) {
@@ -856,34 +858,28 @@ impl LuaGenerator for ReadableLuaGenerator {
         if table_len == 0 {
             self.raw_push_char('}');
         } else {
-            let column_space = self.column_span.checked_sub(self.current_line_length)
-                .unwrap_or(0);
+            let column_space = self.column_span.saturating_sub(self.current_line_length);
             if self.table_fits_on_line(entries, column_space) {
+                let last_index = table_len.saturating_sub(1);
 
-                let last_index = table_len.checked_sub(1).unwrap_or(0);
-
-                entries.iter()
-                    .enumerate()
-                    .for_each(|(index, entry)| {
-                        self.write_table_entry(entry);
-
-                        if index != last_index {
-                            self.raw_push_char(',');
-                            self.raw_push_char(' ');
-                        }
-                    });
+                entries.iter().enumerate().for_each(|(index, entry)| {
+                    self.write_table_entry(entry);
 
+                    if index != last_index {
+                        self.raw_push_char(',');
+                        self.raw_push_char(' ');
+                    }
+                });
             } else {
                 self.push_indentation();
 
-                entries.iter()
-                    .for_each(|entry| {
-                        self.push_new_line();
-                        self.write_indentation();
-                        self.write_table_entry(entry);
+                entries.iter().for_each(|entry| {
+                    self.push_new_line();
+                    self.write_indentation();
+                    self.write_table_entry(entry);
 
-                        self.raw_push_char(',');
-                    });
+                    self.raw_push_char(',');
+                });
 
                 self.pop_indentation();
                 self.push_new_line();
@@ -932,7 +928,8 @@ impl LuaGenerator for ReadableLuaGenerator {
                     self.push_str(&format!("{:.}", float));
 
                     if let Some(exponent) = number.get_exponent() {
-                        let exponent_char = number.is_uppercase()
+                        let exponent_char = number
+                            .is_uppercase()
                             .map(|is_uppercase| if is_uppercase { 'E' } else { 'e' })
                             .unwrap_or('e');
                         self.raw_push_char(exponent_char);
@@ -948,13 +945,21 @@ impl LuaGenerator for ReadableLuaGenerator {
                 ));
 
                 if let Some(exponent) = number.get_exponent() {
-                    let exponent_char = number.is_exponent_uppercase()
+                    let exponent_char = number
+                        .is_exponent_uppercase()
                         .map(|is_uppercase| if is_uppercase { 'P' } else { 'p' })
                         .unwrap_or('p');
                     self.raw_push_char(exponent_char);
                     self.raw_push_str(&format!("{}", exponent));
                 };
             }
+            Binary(number) => {
+                self.push_str(&format!(
+                    "0{}{:b}",
+                    if number.is_b_uppercase() { 'B' } else { 'b' },
+                    number.get_raw_value()
+                ));
+            }
         }
     }
 
@@ -965,8 +970,8 @@ impl LuaGenerator for ReadableLuaGenerator {
             let mut equals = "=".repeat(i);
 
             loop {
-                if value.find(&format!("]{}]", equals)).is_none() {
-                    break
+                if !value.contains(&format!("]{}]", equals)) {
+                    break;
                 } else {
                     i += 1;
                     equals = "=".repeat(i);
@@ -975,9 +980,8 @@ impl LuaGenerator for ReadableLuaGenerator {
 
             self.push_str_and_break_if(
                 &format!("[{}[{}]{}]", equals, value, equals),
-                break_long_string
+                break_long_string,
             );
-
         } else {
             let string = if string.has_single_quote() {
                 if string.has_double_quote() {
