@@ -1,8 +1,4 @@
-use crate::nodes::{
-    Expression,
-    StringExpression,
-    TableExpression,
-};
+use crate::nodes::{Expression, StringExpression, TableExpression};
 
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub enum Arguments {
@@ -32,3 +28,15 @@ impl Default for Arguments {
         Arguments::Tuple(Vec::new())
     }
 }
+
+impl From<TableExpression> for Arguments {
+    fn from(table: TableExpression) -> Self {
+        Self::Table(table)
+    }
+}
+
+impl From<StringExpression> for Arguments {
+    fn from(string: StringExpression) -> Self {
+        Self::String(string)
+    }
+}
