@@ -14,15 +14,15 @@ fn generated_identifier() -> String {
             let character = rng.sample(Alphanumeric);
 
             if i != 0 || !character.is_digit(10) {
-                return character
+                return character;
             }
         })
         .collect();
 
     match identifier.as_ref() {
-        "and" | "break" | "do" | "else" | "elseif" | "end" | "false" | "for"
-        | "function" | "if" | "in" | "local" | "nil" | "not" | "or" | "repeat"
-        | "return" | "then" | "true" | "until" | "while" => generated_identifier(),
+        "and" | "break" | "do" | "else" | "elseif" | "end" | "false" | "for" | "function"
+        | "if" | "in" | "local" | "nil" | "not" | "or" | "repeat" | "return" | "then" | "true"
+        | "until" | "while" => generated_identifier(),
         _ => identifier,
     }
 }
@@ -176,10 +176,8 @@ impl Fuzz<Block> for Block {
         let mut statements = Vec::new();
         let mut last_statement = None;
 
-        if rand::random() {
-            if context.take_statement() {
-                last_statement.replace(LastStatement::fuzz(context));
-            }
+        if rand::random() && context.take_statement() {
+            last_statement.replace(LastStatement::fuzz(context));
         }
 
         while context.take_statement() {
@@ -192,7 +190,7 @@ impl Fuzz<Block> for Block {
 
 impl Fuzz<Statement> for Statement {
     fn fuzz(context: &mut FuzzContext) -> Self {
-        match thread_rng().gen_range(0, 11) {
+        match thread_rng().gen_range(0, 12) {
             0 => AssignStatement::fuzz(context).into(),
             1 => DoStatement::fuzz(&mut context.share_budget()).into(),
             2 => FunctionCall::fuzz(context).into(),
@@ -203,21 +201,24 @@ impl Fuzz<Statement> for Statement {
             7 => LocalFunctionStatement::fuzz(&mut context.share_budget()).into(),
             8 => NumericForStatement::fuzz(&mut context.share_budget()).into(),
             9 => RepeatStatement::fuzz(&mut context.share_budget()).into(),
-            _ => WhileStatement::fuzz(&mut context.share_budget()).into(),
+            10 => WhileStatement::fuzz(&mut context.share_budget()).into(),
+            _ => CompoundAssignStatement::fuzz(&mut context.share_budget()).into(),
         }
     }
 }
 
 impl Fuzz<LastStatement> for LastStatement {
     fn fuzz(context: &mut FuzzContext) -> Self {
-        if rand::random() {
-            Self::Break
-        } else {
-            let normal = Normal::new(0.0, 2.5).unwrap();
-            let mut rng = thread_rng();
-            let length = (rng.sample(normal) as f64).abs().floor() as usize;
+        match thread_rng().gen_range(0, 3) {
+            0 => Self::Break,
+            1 => Self::Continue,
+            _ => {
+                let normal = Normal::new(0.0, 2.5).unwrap();
+                let mut rng = thread_rng();
+                let length = (rng.sample(normal) as f64).abs().floor() as usize;
 
-            Self::Return(generate_expressions(length, context))
+                Self::Return(generate_expressions(length, context))
+            }
         }
     }
 }
@@ -234,6 +235,32 @@ impl Fuzz<AssignStatement> for AssignStatement {
     }
 }
 
+impl Fuzz<CompoundAssignStatement> for CompoundAssignStatement {
+    fn fuzz(context: &mut FuzzContext) -> Self {
+        Self::new(
+            CompoundOperator::fuzz(context),
+            Variable::fuzz(context),
+            Expression::fuzz(context),
+        )
+    }
+}
+
+impl Fuzz<CompoundOperator> for CompoundOperator {
+    fn fuzz(_context: &mut FuzzContext) -> Self {
+        use CompoundOperator::*;
+
+        match thread_rng().gen_range(0, 8) {
+            1 => Plus,
+            2 => Minus,
+            3 => Asterisk,
+            4 => Slash,
+            5 => Percent,
+            6 => Caret,
+            _ => Concat,
+        }
+    }
+}
+
 impl Fuzz<Variable> for Variable {
     fn fuzz(context: &mut FuzzContext) -> Self {
         use Variable::*;
@@ -272,7 +299,11 @@ impl Fuzz<FunctionName> for FunctionName {
         Self::new(
             generated_identifier(),
             generated_identifiers(function_name_field_length()),
-            if rand::random() { Some(generated_identifier()) } else { None },
+            if rand::random() {
+                Some(generated_identifier())
+            } else {
+                None
+            },
         )
     }
 }
@@ -281,10 +312,7 @@ impl Fuzz<GenericForStatement> for GenericForStatement {
     fn fuzz(context: &mut FuzzContext) -> Self {
         Self::new(
             generated_identifiers(1),
-            generate_at_least_one_expression(
-                generic_for_expression_length(),
-                context
-            ),
+            generate_at_least_one_expression(generic_for_expression_length(), context),
             Block::fuzz(context),
         )
     }
@@ -295,11 +323,13 @@ impl Fuzz<IfStatement> for IfStatement {
         Self::new(
             generate_at_least_one_expression(if_branch_count(), context)
                 .into_iter()
-                .map(|condition| {
-                    IfBranch::new(condition, Block::fuzz(&mut context.share_budget()))
-                })
+                .map(|condition| IfBranch::new(condition, Block::fuzz(&mut context.share_budget())))
                 .collect(),
-            if rand::random() { Some(Block::fuzz(&mut context.share_budget())) } else { None },
+            if rand::random() {
+                Some(Block::fuzz(&mut context.share_budget()))
+            } else {
+                None
+            },
         )
     }
 }
@@ -330,7 +360,11 @@ impl Fuzz<NumericForStatement> for NumericForStatement {
             generated_identifier(),
             Expression::fuzz(context),
             Expression::fuzz(context),
-            if rand::random() { Some(Expression::fuzz(context)) } else { None },
+            if rand::random() {
+                Some(Expression::fuzz(context))
+            } else {
+                None
+            },
             Block::fuzz(context),
         )
     }
@@ -411,11 +445,7 @@ impl Fuzz<BinaryExpression> for BinaryExpression {
             right = Expression::Parenthese(right.into());
         }
 
-        Self::new(
-            operator,
-            left,
-            right,
-        )
+        Self::new(operator, left, right)
     }
 }
 
@@ -468,7 +498,7 @@ impl Fuzz<FunctionCall> for FunctionCall {
                 Some(generated_identifier())
             } else {
                 None
-            }
+            },
         )
     }
 }
@@ -491,13 +521,10 @@ impl Fuzz<IndexExpression> for IndexExpression {
 
 impl Fuzz<NumberExpression> for NumberExpression {
     fn fuzz(_context: &mut FuzzContext) -> Self {
-        if rand::random() {
-            DecimalNumber::new(thread_rng().gen()).into()
-        } else {
-            HexNumber::new(
-                thread_rng().gen_range(0, 100_000),
-                rand::random()
-            ).into()
+        match thread_rng().gen_range(0, 4) {
+            0 => DecimalNumber::new(thread_rng().gen()).into(),
+            1 => HexNumber::new(thread_rng().gen_range(0, 100_000), rand::random()).into(),
+            _ => BinaryNumber::new(thread_rng().gen_range(0, 1_000_000), rand::random()).into(),
         }
     }
 }
@@ -514,12 +541,10 @@ impl Fuzz<Prefix> for Prefix {
                 3 => Index(IndexExpression::fuzz(context).into()),
                 _ => Parenthese(Expression::fuzz(context)),
             }
+        } else if rand::random() {
+            Call(FunctionCall::fuzz(context))
         } else {
-            if rand::random() {
-                Call(FunctionCall::fuzz(context))
-            } else {
-                Identifier(generated_identifier())
-            }
+            Identifier(generated_identifier())
         }
     }
 }
@@ -540,7 +565,7 @@ impl Fuzz<StringExpression> for StringExpression {
             iter::repeat(())
                 .take(length as usize)
                 .map(|()| GEN_CHARSET[rng.gen_range(0, GEN_CHARSET.len())] as char)
-                .collect()
+                .collect(),
         )
     }
 }
@@ -557,7 +582,7 @@ impl Fuzz<TableExpression> for TableExpression {
                         None
                     }
                 })
-                .collect()
+                .collect(),
         )
     }
 }
@@ -570,12 +595,10 @@ impl Fuzz<TableEntry> for TableEntry {
                 1 => Self::Index(Expression::fuzz(context), Expression::fuzz(context)),
                 _ => Self::Value(Expression::fuzz(context)),
             }
+        } else if rand::random() {
+            Self::Field(generated_identifier(), Expression::fuzz(context))
         } else {
-            if rand::random() {
-                Self::Field(generated_identifier(), Expression::fuzz(context))
-            } else {
-                Self::Value(Expression::fuzz(context))
-            }
+            Self::Value(Expression::fuzz(context))
         }
     }
 }
